API Reference
=============

Installation
------------

The libary is available from `PyPI <https://pypi.org/project/papass/>`_. You can install
it like so:

.. code-block:: console

    $ pip install papass

API
---

.. automodule:: papass
    :members:
    :special-members:
    :show-inheritance:
